<?php
namespace App\Factory;

use App\Exception;

class OrderFactory {
    private $connection;
    private $util;

    public function __construct (\App\Util\Util $util,
            \Doctrine\DBAL\Connection $connection) {
        $this->util = $util;
        $this->connection = $connection;
    }
    
    public function getDefaultParams($cdfilial)
    {
        $sql = "
            SELECT PV.CDFILIAL, PV.CDVENDEDOR, V.CDOPERADOR, V.CDCAIXA, C.CDLOJA, PV.CDCLIENTE,
                   NVL(PV.CDCONSUMIDOR, PV.CDCONSUMIDPADRAO) CDCONSUMIDOR, L.NRMESAPADRAO AS NRMESA, V.NMFANVEN, L.IDCONTROPROD, ED.SGESTADO
              FROM PARAVEND PV
         LEFT JOIN VENDEDOR V
                ON V.CDVENDEDOR = PV.CDVENDEDOR
         LEFT JOIN CAIXA C
                ON C.CDCAIXA = V.CDCAIXA
         LEFT JOIN LOJA L
                ON L.CDLOJA = C.CDLOJA
               AND L.CDFILIAL = PV.CDFILIAL
         LEFT JOIN ENDEFILI ED
                ON ED.CDFILIAL = PV.CDFILIAL
             WHERE PV.CDFILIAL = :CDFILIAL
            ORDER BY NRMESA, IDCONTROPROD, CDCONSUMIDOR, CDCLIENTE, CDLOJA, CDCAIXA, CDOPERADOR, CDVENDEDOR
        ";

        $params = [
            ':CDFILIAL' => $cdfilial
        ];
        
        return $this->connection->fetchAssoc($sql, $params);
    }

    public function saveVendarest ($cdfilial, $nrvendarest, $cdloja, $nrmesa, $cdvendedor, $cdoperador, $cdcliente, $cdconsumidor, $sgestado)
    {
        $sql = "
            INSERT INTO VENDAREST
    			(CDFILIAL, NRVENDAREST, CDLOJA, NRMESA, CDVENDEDOR,
    			DTHRABERMESA, CDOPERADOR, NRPESMESAVEN,
    			CDCLIENTE, CDCONSUMIDOR, IDPEDIDOPAGO)
    		VALUES
    			(:CDFILIAL, :NRVENDAREST, :CDLOJA, :NRMESA,
    			:CDVENDEDOR, TO_DATE(:CURRDATE, 'DD/MM/YYYY HH24:MI:SS'), :CDOPERADOR,
    			:NRPESMESAVEN, :CDCLIENTE, :CDCONSUMIDOR, :IDPEDIDOPAGO)";
    			
    	date_default_timezone_set($this->util->getCurrentTimezone(strtoupper($sgestado)));
    	
    	$params = [
    	    "CDFILIAL"     => $cdfilial,
            "NRVENDAREST"  => $nrvendarest,
            "CDLOJA"       => $cdloja,
            "NRMESA"       => $nrmesa,
            "CDVENDEDOR"   => $cdvendedor,
            "CURRDATE"     => date("d/m/Y H:i:s"),
            "CDOPERADOR"   => $cdoperador,
            "NRPESMESAVEN" => "1",
            "CDCLIENTE"    => $cdcliente,
            "CDCONSUMIDOR" => $cdconsumidor,
            "IDPEDIDOPAGO" => "S"
    	];

    	return $this->connection->executeQuery($sql, $params);
    }
    
    public function saveComandaven ($cdfilial, $nrvendarest, $nrcomanda, $nrcomandaext, $cdloja, $dscomanda, $idstcomanda,
                                    $vracrcomanda, $consumerData, $dsobscomanda, $nrpedmobile, $consumerIdentifier, $dlvMethod)
    {
        $sql = "
            INSERT INTO COMANDAVEN 
                (CDFILIAL, NRVENDAREST, NRCOMANDA, NRCOMANDAEXT, 
    	        CDLOJA, DSCOMANDA, IDSTCOMANDA, 
    	        VRACRCOMANDA, CDPAIS, SGESTADO, 
    	        CDMUNICIPIO, NRCEPCONSCOMAND, CDBAIRRO, DSBAIRRO, NRENDECONSCOMAN,
    	        DSENDECONSCOMAN, DSCOMPLENDCOCOM, DSREFENDCONSCOM, DSOBSCOMANDA,
    	        IDORGCMDVENDA, NRPEDMOBILE, DSCONSUMIDOR, IDRETBALLOJA)
    	    VALUES 
    	        (:CDFILIAL, :NRVENDAREST, :NRCOMANDA, :NRCOMANDAEXT, 
    	        :CDLOJA, :DSCOMANDA, :IDSTCOMANDA, 
    	        :VRACRCOMANDA, :CDPAIS, :SGESTADO, 
    	        :CDMUNICIPIO, :NRCEPCONSCOMAND, :CDBAIRRO, :DSBAIRRO, :NRENDECONSCOMAN,
    	        :DSENDECONSCOMAN, :DSCOMPLENDCOCOM, :DSREFENDCONSCOM, :DSOBSCOMANDA,
    	        :IDORGCMDVENDA, :NRPEDMOBILE, :DSCONSUMIDOR, :IDRETBALLOJA)";
    	
    	$params = [
    	    "CDFILIAL"        => $cdfilial,
            "NRVENDAREST"     => $nrvendarest,
            "NRCOMANDA"       => $nrcomanda,
            "NRCOMANDAEXT"    => $nrcomandaext,
            "CDLOJA"          => $cdloja,
            "DSCOMANDA"       => $dscomanda,
            "IDSTCOMANDA"     => $idstcomanda,
            "VRACRCOMANDA"    => $this->util->toFloat($vracrcomanda),
            "CDPAIS"          => "0055",
            "SGESTADO"        => $consumerData['SGESTADO'],
            "CDMUNICIPIO"     => $consumerData['CDMUNICIPIO'],
            "NRCEPCONSCOMAND" => $consumerData['NRCEPCONS'],
            "CDBAIRRO"        => $consumerData['CDBAIRRO'],
            "DSBAIRRO"        => substr($consumerData['NMBAIRCONS'], 0, 100),
            "NRENDECONSCOMAN" => substr($consumerData['NRENDECONS'], 0, 10),
            "DSENDECONSCOMAN" => substr($consumerData['DSENDECONS'], 0, 50),
            "DSCOMPLENDCOCOM" => substr($consumerData['DSCOMPLENDECONS'], 0, 200),
            "DSREFENDCONSCOM" => substr($consumerData['DSREFERENDECONS'], 0, 2000),
            "DSOBSCOMANDA"    => substr($dsobscomanda, 0, 2000),
            "IDORGCMDVENDA"   => "DLV_ANT",
            "NRPEDMOBILE"     => 'ANT'.$nrpedmobile,
            "DSCONSUMIDOR"    => substr($consumerIdentifier, 0, 50),
            "IDRETBALLOJA"    => $dlvMethod
    	];

    	return $this->connection->executeQuery($sql, $params);
    }
    
    public function validateDuplication ($order, $branch)
    {
        $sql = "
            SELECT C.NRPEDMOBILE
    		  FROM COMANDAVEN C
    		  JOIN VENDAREST V
    		    ON V.NRVENDAREST = C.NRVENDAREST
    		   AND V.CDFILIAL = C.CDFILIAL
    		 WHERE C.NRPEDMOBILE   = :NRPEDMOBILE
    		   AND V.CDFILIAL      = :CDFILIAL
    		   AND C.IDORGCMDVENDA = :IDORGCMDVENDA
    		   AND DTHRABERMESA >= SYSDATE - 1
        ";
        
        $params = [
            ":CDFILIAL"    => $branch,
            ":NRPEDMOBILE" => "ANT".$order,
            ":IDORGCMDVENDA" => 'DLV_ANT'
        ];
        
        $result = $this->connection->fetchAll($sql, $params);
        return empty($result);
    }
    
    public function cancelOrder ($cancelOrder)
    {
        $sql = "
            UPDATE COMANDAVEN
		       SET IDSTCOMANDA = '4'
		     WHERE CDFILIAL = :CDFILIAL
	           AND NRCOMANDA = :NRCOMANDA
	           AND NRVENDAREST = :NRVENDAREST
	           AND IDORGCMDVENDA = 'DLV_ANT'";
        
		$params = array(
			':CDFILIAL'	 => $cancelOrder["BRANCHID"], 
			':NRCOMANDA' => $cancelOrder["ORDERNUMBER"],
			':NRVENDAREST' => $cancelOrder["SELLNUMBER"]
		);
		
		$this->connection->executeQuery($sql, $params);
		
		$this->syncOrder($cancelOrder);
	}
	
	public function syncOrder ($orderDetails)
	{
        $sql = "
	        UPDATE VENDAREST
		       SET IDSINCMSDE = 'N'
	        WHERE CDFILIAL = :CDFILIAL
	            AND NRVENDAREST = :NRVENDAREST";
        $params = array(
            ':CDFILIAL' => $orderDetails["BRANCHID"],
            ':NRVENDAREST' => $orderDetails["SELLNUMBER"]
       );
       
       $this->connection->executeQuery($sql, $params);
	}
	
	public function getOrderDataById ($orderId)
	{
	    $sql = "
	        SELECT CDFILIAL AS BRANCHID, 
	               NRCOMANDA AS ORDERNUMBER, 
	               NRVENDAREST AS SELLNUMBER,
	               IDSTCOMANDA
	           FROM COMANDAVEN
	       WHERE NRPEDMOBILE = :NRPEDMOBILE
	    ";
	    $params = array(
            ':NRPEDMOBILE' => 'ANT'.$orderId
       );

        return $this->connection->fetchAssoc($sql, $params);
	}
	
	public function getBranch ($token)
	{

        $sql = "
            SELECT CDFILIAL 
              
              FROM INTEGRACAOFILI IF 
              
              JOIN INTEGRACAO I
                ON IF.CDINTEGRACAO = I.CDINTEGRACAO
            
             WHERE I.IDINTEGRACAO  = :IDINTEGRACAO
              AND IF.IDTOKEN like '%' || :IDTOKEN || '%'
        ";

        $params = [
            ":IDINTEGRACAO" => "ANT",
            ":IDTOKEN"      => (string)$token
        ];
        $branchInfo = $this->connection->fetchAssoc($sql, $params);
        
        if(empty($branchInfo)) {
            throw new Exception\ParamsException("Não existe filial associada ao token $token (id do estabelecimento na Anota Aí)", 101);
        }

        if(empty($branchInfo['CDFILIAL'])) {
            throw new Exception\ParamsException("Não existe filial associada ao token $token (id do estabelecimento na Anota Aí)", 101);
        }

        return $branchInfo['CDFILIAL'];
    }
	
	public function getOrderDetailsById ($resourceId)
	{
	    $sql = "
	        SELECT CDFILIAL, NRCOMANDAEXT, IDSTCOMANDA 
	           FROM COMANDAVEN
	       WHERE NRPEDMOBILE = :NRPEDMOBILE
	    ";
	    $params = array(
            ':NRPEDMOBILE' => 'ANT'.$resourceId
       );

        return $this->connection->fetchAssoc($sql, $params);
	}
	
    //Prevents teknisa from crazy discount logics by partners ¯\_(ツ)_/¯
    public function validateOrder ($cdFilial, $nrVendaRest)
    {
            $taxSQL = "
                SELECT VRACRCOMANDA
                  FROM COMANDAVEN
                 WHERE NRVENDAREST      = :NRVENDAREST
                   AND CDFILIAL         = :CDFILIAL
            ";
    
            $itemsSQL = "
                SELECT QTPRODCOMVEN, VRPRECCOMVEN, VRDESCCOMVEN
                  FROM ITCOMANDAVEN
                 WHERE NRVENDAREST      = :NRVENDAREST
                   AND CDFILIAL         = :CDFILIAL
            ";
    
            $entradasSQL = "
                SELECT VRMOVIVENDDLV FROM MOVCAIXADLV
                 WHERE NRVENDAREST      = :NRVENDAREST
                   AND CDFILIAL         = :CDFILIAL
                   AND IDTIPOMOVIVEDLV  = 'E'
            ";
    
            $saidasSQL = "
                SELECT VRMOVIVENDDLV FROM MOVCAIXADLV
                 WHERE NRVENDAREST      = :NRVENDAREST
                   AND CDFILIAL         = :CDFILIAL
                   AND IDTIPOMOVIVEDLV  = 'S'
            ";
            
            $params = [
                ":CDFILIAL"     => $cdFilial,
                ":NRVENDAREST"  => $nrVendaRest
            ];
    
            $taxData      = $this->connection->fetchAssoc($taxSQL, $params);
            $itemsData    = $this->connection->fetchAll($itemsSQL, $params);
            $entradasData = $this->connection->fetchAll($entradasSQL, $params);
            $saidasData   = $this->connection->fetchAll($saidasSQL, $params);
    
            $taxSum      = isset($taxData['VRACRCOMANDA']) ? (string)$this->formatNumber($taxData['VRACRCOMANDA']) : "0.00";
            $itemsSum    = "0.00";
            $entradasSum = "0.00";
            $saidasSum   = "0.00";
    
            foreach($itemsData as $itemData) {
                $mul      = bcmul($this->formatNumber($itemData['VRPRECCOMVEN']), $this->formatNumber($itemData['QTPRODCOMVEN']), 2);
                $sub      = bcsub($mul, $this->formatNumber($itemData['VRDESCCOMVEN']), 2);
                $itemsSum = bcadd($itemsSum, $sub, 2);
            }
    
            foreach($entradasData as $entradaData) {
                $entradasSum = bcadd($entradasSum, $this->formatNumber($entradaData['VRMOVIVENDDLV']), 2);
            }
    
            foreach($saidasData as $saidaData) {
                $saidasSum = bcadd($saidasSum, $this->formatNumber($saidaData['VRMOVIVENDDLV']), 2);
            }
    
            $orderSum    = bcadd($itemsSum, $taxSum, 2);
            $paymentsSum = bcsub($entradasSum, $saidasSum, 2);

            if(bccomp($orderSum, $paymentsSum) != 0) {
                throw new Exception\ParamsException("Não foi possível processar o pedido, existe uma divergencia entre os itens do pedido e o valor pago.<br>Valor dos itens: $orderSum | Valor pago: $paymentsSum");
            }
        }
    
    private function formatNumber ($number)
    {
        return str_replace(",", ".", $number);
    }
        
    public function getDeliveryMethodParams ($token)
    {
        $sql = "
            SELECT IF.IDTOKEN, IF.CDFILIAL, IF.IDUTLENTRETERC, IF.IDRETTXENTR, I.IDTOKENINTGERAL, I.IDUTLVNDPDRPALC, IF.CDLOJA, IF.CDCAIXA, IF.AUTHTOKEN, IF.AUTHTKNDTCRIAC
              FROM INTEGRACAOFILI IF
              JOIN INTEGRACAO I
                ON IF.CDINTEGRACAO = I.CDINTEGRACAO
             WHERE IF.IDTOKENINTGERALFILI like '%' || :IDTOKENINTGERALFILI || '%'
                AND I.IDINTEGRACAO = 'ANT'
        ";

        $params = [
            ':IDTOKENINTGERALFILI' => $token
        ];

        return $this->connection->fetchAssoc($sql, $params);
    }
    
    public function validateOperator ($generalParams)
    {
        $sql = "
            SELECT * FROM FILIOPER
             WHERE CDOPERADOR   = :CDOPERADOR
               AND CDFILIAL     = :CDFILIAL
        ";
        
        $params = [
            ":CDFILIAL"   => $generalParams["CDFILIAL"],
            ":CDOPERADOR" => $generalParams["CDOPERADOR"]
        ];
        
        return $this->connection->fetchAssoc($sql, $params);
    }
    
    public function insertSale ($sale, $generalParams, $consumer)
    {
        $sql = "
            INSERT INTO VENDAREST
    			(CDFILIAL, NRVENDAREST, CDLOJA, NRMESA, CDVENDEDOR,
    			DTHRABERMESA, DTHRFECHMESA, CDOPERADOR, NRPESMESAVEN,
    			CDCLIENTE, CDCONSUMIDOR, IDPEDIDOPAGO)
    		VALUES
    			(:CDFILIAL, :NRVENDAREST, :CDLOJA, :NRMESA,
    			:CDVENDEDOR, TO_DATE(:CURRDATE, 'dd/mm/yyyy hh24:mi:ss'), null, :CDOPERADOR,
    			:NRPESMESAVEN, :CDCLIENTE, :CDCONSUMIDOR, 'S')";
    			
    	date_default_timezone_set($this->util->getCurrentTimezone(strtoupper($generalParams["SGESTADO"])));
    	
    	$params = [
    	    ":CDFILIAL"     => $generalParams["CDFILIAL"],
            ":NRVENDAREST"  => $sale,
            ":CDLOJA"       => $generalParams["CDLOJA"],
            ":NRMESA"       => "",
            ":CDVENDEDOR"   => $generalParams["CDVENDEDOR"],
            ":CURRDATE"     => date("d/m/Y H:i:s"),
            ":CDOPERADOR"   => $generalParams["CDOPERADOR"],
            ":NRPESMESAVEN" => "1",
            ":CDCLIENTE"    => $consumer["CDCLIENTE"],
            ":CDCONSUMIDOR" => $consumer["CDCONSUMIDOR"]    
    	];
    	
    	$this->connection->executeQuery($sql, $params);
    }
    
    public function insertSaleCommand ($generalParams, $order, $consumer)
    {
        $sql = "
            INSERT INTO COMANDAVEN 
                (CDFILIAL, NRVENDAREST, NRCOMANDA, NRCOMANDAEXT, 
    	        CDLOJA, DSCOMANDA, IDSTCOMANDA, SGSEXOCON, 
    	        TXMOTIVCANCE, VRACRCOMANDA, VRDESCOMANDA, CDPAIS, SGESTADO, 
    	        CDMUNICIPIO, NRCEPCONSCOMAND, CDBAIRRO, DSBAIRRO, NRENDECONSCOMAN,
    	        DSENDECONSCOMAN, DSCOMPLENDCOCOM, DSREFENDCONSCOM, DSOBSCOMANDA,
    	        IDORGCMDVENDA, IDRETBALLOJA, NRPEDMOBILE, NRLATPEDIDO, NRLONGPEDIDO, 
    	        DSAREAATEND, IDSINCAGENDA, DTHRAGENDADA, DSCONSUMIDOR, NRCONTATOCON)
    	    VALUES 
    	        (:CDFILIAL, :NRVENDAREST, :NRCOMANDA, :NRCOMANDAEXT, 
    	        :CDLOJA, :DSCOMANDA, :IDSTCOMANDA, :SGSEXOCON, 
    	        :TXMOTIVCANCE, :VRACRCOMANDA, :VRDESCOMANDA, :CDPAIS, :SGESTADO, 
    	        :CDMUNICIPIO, :NRCEPCONSCOMAND, :CDBAIRRO, :DSBAIRRO, :NRENDECONSCOMAN,
    	        :DSENDECONSCOMAN, :DSCOMPLENDCOCOM, :DSREFENDCONSCOM, :DSOBSCOMANDA,
    	        :IDORGCMDVENDA, :IDRETBALLOJA, :NRPEDMOBILE, :NRLATPEDIDO,
    	        :NRLONGPEDIDO, :DSAREAATEND, :IDSINCAGENDA, TO_DATE(:DTHRAGENDADA, 'dd/mm/yyyy hh24:mi:ss'), :DSCONSUMIDOR, :NRCONTATOCON)";
    	        
    	$consumerName = strtoupper($this->util->removeAcentos($order["customer"]["name"]));
    	
    	$params = [
    	    ":CDFILIAL"        => $generalParams["CDFILIAL"],
            ":NRVENDAREST"     => $order["NRVENDAREST"],
            ":NRCOMANDA"       => $order["NRCOMANDA"],
            ":NRCOMANDAEXT"    => $order["shortReference"],
            ":CDLOJA"          => $generalParams["CDLOJA"],
            ":DSCOMANDA"       => "DLV_".$order["NRCOMANDA"],
            ":IDSTCOMANDA"     => $order["IDSTCOMANDA"],
            ":SGSEXOCON"       => "M",
            ":TXMOTIVCANCE"    => "",
            ":VRACRCOMANDA"    => $this->util->tofloat($order["deliveryFee"]),
            ":VRDESCOMANDA"    => 0,
            ":CDPAIS"          => "0055",
            ":SGESTADO"        => $order["deliveryAddress"]["state"], 
            ":CDMUNICIPIO"     => $consumer["CDMUNICIPIO"],
            ":NRCEPCONSCOMAND" => $order["deliveryAddress"]["postalCode"],
            ":CDBAIRRO"        => $consumer["CDBAIRRO"],
            ":DSBAIRRO"        => substr($order["deliveryAddress"]["neighborhood"], 0, 99),
            ":NRENDECONSCOMAN" => substr((empty($order["deliveryAddress"]["streetNumber"]) ? "" : $order["deliveryAddress"]["streetNumber"]), 0, 10),
            ":DSENDECONSCOMAN" => substr($order["deliveryAddress"]["streetName"], 0, 49),
            ":DSCOMPLENDCOCOM" => (isset($order["deliveryAddress"]["complement"]) && !empty($order["deliveryAddress"]["complement"])) ? $order["deliveryAddress"]["complement"] : "",
            ":DSREFENDCONSCOM" => (isset($order["deliveryAddress"]["reference"]) && !empty($order["deliveryAddress"]["reference"])) ? $order["deliveryAddress"]["reference"] : "",
            ":DSOBSCOMANDA"    => isset($generalParams['DSOBSCOMANDA']) ? $generalParams['DSOBSCOMANDA'] : "",
            ":IDORGCMDVENDA"   => "DLV_ANT",
            ":IDRETBALLOJA"    => $order["type"] === "TAKEOUT" ? "S" : "N",
            ":NRPEDMOBILE"     => "ANT".$order["id"],
            ":NRLATPEDIDO"     => null,
            ":NRLONGPEDIDO"    => null,
            ":DSAREAATEND"     => $consumer["DSAREAATEND"],
            ":IDSINCAGENDA"    => substr(($order["IDSINCAGENDA"]), 0, 1),
            ":DTHRAGENDADA"    => $order["DTHRAGENDADA"],
            ":DSCONSUMIDOR"    => substr((isset($consumerName) ? $consumerName : ""), 0, 50),
            ":NRCONTATOCON"    => substr((isset($order["customer"]["telephone"]) ? $order["customer"]["telephone"] : ""), 0, 32),
    	];

    	$this->connection->executeQuery($sql, $params);
    }
    
    public function insertCashMoviment ($order, $value, $consumer)
    {
        $sql = "
            INSERT INTO MOVCAIXADLV
        		(CDFILIAL, NRVENDAREST, NRSEQMOVDLV, IDTIPOMOVIVEDLV,
        		VRMOVIVENDDLV, CDTIPORECE, CDCLIENTE, CDCONSUMIDOR,
        		NRCARTBANCODLV)
        	VALUES
        		(:CDFILIAL, :NRVENDAREST, :NRSEQMOVDLV, :IDTIPOMOVIVEDLV,
        		:VRMOVIVENDDLV, :CDTIPORECE, :CDCLIENTE, :CDCONSUMIDOR,
        		:NRCARTBANCODLV)";

        $params = [
            ":CDFILIAL"        => $order["cdFilial"],
            ":NRVENDAREST"     => $order["NRVENDAREST"],
            ":NRSEQMOVDLV"     => $order["NRSEQMOVDLV"],
            ":IDTIPOMOVIVEDLV" => "E",
            ":CDCLIENTE"       => $consumer["CDCLIENTE"],
            ":CDCONSUMIDOR"    => $consumer["CDCONSUMIDOR"],
            ":CDTIPORECE"      => $order["CDTIPORECE"],
            ":VRMOVIVENDDLV"   => $this->util->tofloat($value),
            ":NRCARTBANCODLV"  => null
        ];
        
        $this->connection->executeQuery($sql, $params);
    }
    
     public function insertChange ($order, $value, $generalParams, $consumer, $movCaixa, $cdTipoRece)
     {
        $sql = "
            INSERT INTO MOVCAIXADLV
        		(CDFILIAL, NRVENDAREST, NRSEQMOVDLV, IDTIPOMOVIVEDLV,
        		VRMOVIVENDDLV, CDTIPORECE, CDCLIENTE, CDCONSUMIDOR,
        		NRCARTBANCODLV)
        	VALUES
        		(:CDFILIAL, :NRVENDAREST, :NRSEQMOVDLV, :IDTIPOMOVIVEDLV,
        		:VRMOVIVENDDLV, :CDTIPORECE, :CDCLIENTE, :CDCONSUMIDOR,
        		:NRCARTBANCODLV)";
        
        $params = [
            ":CDFILIAL"        => $order["branch"],
            ":NRVENDAREST"     => $order["NRVENDAREST"],
            ":NRSEQMOVDLV"     => $movCaixa,
            ":IDTIPOMOVIVEDLV" => "S",
            ":CDCLIENTE"       => $consumer["CDCLIENTE"],
            ":CDCONSUMIDOR"    => $consumer["CDCONSUMIDOR"],
            ":CDTIPORECE"      => $cdTipoRece,
            ":VRMOVIVENDDLV"   => $this->util->toFloat($value),
            ":NRCARTBANCODLV"  => null
        ];
        
        $this->connection->executeQuery($sql, $params);
    }
}